@@ -110,18 +110,15 @@ class DynaliteDevices:
         self._poll_timer = configurator.poll_timer
         self._default_fade = configurator.default_fade
         self._area = configurator.area
+        self._default_presets = configurator.default_presets
         # now register the channels and presets and ask for initial status if needed
         for area in self._area:
             if self._active in [ACTIVE_INIT, ACTIVE_ON]:
                 self._dynalite.request_area_preset(area)
             for channel in self._area[area][CONF_CHANNEL]:
                 self.create_channel_if_new(area, channel)
-                if (
-                    CONF_TEMPLATE not in self._area[area]
-                    or self._area[area][CONF_TEMPLATE] != CONF_TIME_COVER
-                ):
-                    if self._active in [ACTIVE_INIT, ACTIVE_ON]:
-                        self._dynalite.request_channel_level(area, channel)
+                if self._active in [ACTIVE_INIT, ACTIVE_ON]:
+                    self._dynalite.request_channel_level(area, channel)
             for preset in self._area[area][CONF_PRESET]:
                 self.create_preset_if_new(area, preset)
         # register the rooms (switches on presets 1/4)
@@ -243,7 +240,7 @@ class DynaliteDevices:
         if preset not in area_config[CONF_PRESET]:
             area_config[CONF_PRESET][preset] = DynaliteConfig.configure_preset(
                 preset,
-                {},
+                self._default_presets.get(preset, {}),
                 area_config[CONF_FADE],
                 CONF_TEMPLATE in area_config or not self._auto_discover,
             )
