@@ -28,6 +28,11 @@ class DynaliteChannelLightDevice(DynaliteChannelBaseDevice):
         """Return the brightness of this light between 0..255."""
         return int(self._level * 255)
 
+    @property
+    def level(self) -> float:
+        """Return the brightness of this light between 0..255."""
+        return self._level
+
     @property
     def direction(self) -> str:
         """Return the brightness of this light between 0..1."""
